Documentation
¶
Overview ¶
Package accessor provides random access to pxar archives.
Index ¶
- type Accessor
- func (a *Accessor) ListDirectory(dirOffset int64) ([]pxar.Entry, error)
- func (a *Accessor) Lookup(path string) (*pxar.Entry, error)
- func (a *Accessor) ReadEntryAt(offset int64) (*pxar.Entry, error)
- func (a *Accessor) ReadFileContent(entry *pxar.Entry) ([]byte, error)
- func (a *Accessor) ReadRoot() (*pxar.Entry, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Accessor ¶
type Accessor struct {
// contains filtered or unexported fields
}
Accessor provides random access to entries in a pxar archive.
func NewAccessor ¶
func NewAccessor(reader io.ReadSeeker, payloadReader ...io.ReadSeeker) *Accessor
NewAccessor creates an accessor for random access to a pxar archive. For split archives (v2 format), provide the payload reader as the second argument.
func (*Accessor) ListDirectory ¶
ListDirectory lists entries in a directory at the given offset. The offset should point to the start of the directory's FILENAME range.
func (*Accessor) ReadEntryAt ¶
ReadEntryAt reads a pxar entry at the given archive offset.
func (*Accessor) ReadFileContent ¶
ReadFileContent reads the content of a file entry from the archive.
Click to show internal directories.
Click to hide internal directories.